==> Cosmos.uv3.10.tar.gz: Tracking/cgetctau.f <==
c     ---------------------------------------------------------------------
c          cgettauc:  get (mean life time) x (light velocity)  of
c      a given particle 
c
      subroutine cgetctau(proj, ctau)

      implicit none

#include  "Zglobalc.h"
#include  "Zlife.h"
#include  "Zptcl.h"
#include  "Zcode.h"
c     **************************************************
      record /ptcl/ proj
      real*8 ctau
c
c
      real*8 tcpi, tck, tcmu, tcks, tckl, tcpi0, tcd0, tcdc

      parameter (tcpi=t0pi*c, tck=t0k*c,
     *           tcmu=t0mu*c, tcks=t0ks*c,
     *           tckl=t0kl*c, 
     *           tcpi0=t0pi0*c, tcd0=t0d0*c,
     *           tcdc =t0dc*c)

      if(proj.code .eq. kpion) then
          if(proj.charge .ne. 0) then
             ctau = tcpi
          else
             ctau = tcpi0
          endif
      elseif(proj.code .eq. kkaon) then
         if(proj.charge .ne. 0) then
            ctau = tck
         elseif(proj.subcode .eq. k0l) then
            ctau = tckl
         else
            ctau = tcks
         endif
      elseif(proj.code .eq. kmuon) then
         ctau = tcmu
      elseif(proj.code .eq. knnb) then
         ctau =0.
      elseif(proj.code .eq. kddb) then
         ctau = 0.
      elseif(proj.code .eq. kdmes) then
         if(proj.charge .eq. 0) then
            ctau = tcd0
         else
            ctau = tcdc
         endif
      elseif(proj.code .eq. krho) then
         ctau = 0.
      elseif(proj.code .eq. kphi) then
         ctau =0.
      elseif(proj.code .eq. komega) then
         ctau = 0.
      elseif(proj.code .eq. keta ) then
         ctau = 0.
      else
         ctau = Infty
      endif
      end

==> Cosmos.uv3.50.tar.gz: Tracking/cgetctau.f <==
c     ---------------------------------------------------------------------
c          cgettauc:  get (mean life time) x (light velocity)  of
c      a given particle 
c
      subroutine cgetctau(proj, ctau)

      implicit none

#include  "Zglobalc.h"
#include  "Zlife.h"
#include  "Zptcl.h"
#include  "Zcode.h"
c     **************************************************
      record /ptcl/ proj
      real*8 ctau
c
c
      real*8 tcpi, tck, tcmu, tcks, tckl, tcpi0, tcd0, tcdc, 
     *       tceta   

      parameter (tcpi=t0pi*c, tck=t0k*c,
     *           tcmu=t0mu*c, tcks=t0ks*c,
     *           tckl=t0kl*c, 
     *           tcpi0=t0pi0*c, tcd0=t0d0*c,
     *           tcdc =t0dc*c, tceta= t0eta*c)

      if(proj.code .eq. kpion) then
          if(proj.charge .ne. 0) then
             ctau = tcpi
          else
             ctau = tcpi0
          endif
      elseif(proj.code .eq. kkaon) then
         if(proj.charge .ne. 0) then
            ctau = tck
         elseif(proj.subcode .eq. k0l) then
            ctau = tckl
         else
            ctau = tcks
         endif
      elseif(proj.code .eq. kmuon) then
         ctau = tcmu
      elseif(proj.code .eq. knnb) then
         ctau =0.
      elseif(proj.code .eq. kddb) then
         ctau = 0.
      elseif(proj.code .eq. kdmes) then
         if(proj.charge .eq. 0) then
            ctau = tcd0
         else
            ctau = tcdc
         endif
      elseif(proj.code .eq. krho) then
         ctau = 0.
      elseif(proj.code .eq. kphi) then
         ctau =0.
      elseif(proj.code .eq. komega) then
         ctau = 0.
      elseif(proj.code .eq. keta ) then
         ctau = tceta
      else
         ctau = Infty
      endif
      end
